==> apache-opennlp_1.9.1.orig.tar.gz: apache-opennlp-1.9.1-src/opennlp-tools/src/test/java/opennlp/tools/parser/lang/en/HeadRulesTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.parser.lang.en;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;

import org.junit.Assert;
import org.junit.Test;

public class HeadRulesTest {

  @Test
  public void testSerialization() throws IOException {
    InputStream headRulesIn =
        HeadRulesTest.class.getResourceAsStream("/opennlp/tools/parser/en_head_rules");

    HeadRules headRulesOrginal = new HeadRules(new InputStreamReader(headRulesIn, "UTF-8"));

    ByteArrayOutputStream out = new ByteArrayOutputStream();
    headRulesOrginal.serialize(new OutputStreamWriter(out, "UTF-8"));
    out.close();

    HeadRules headRulesRecreated = new HeadRules(new InputStreamReader(
        new ByteArrayInputStream(out.toByteArray()), "UTF-8"));

    Assert.assertEquals(headRulesOrginal, headRulesRecreated);
  }
}

==> apache-opennlp_1.9.4.orig.tar.gz: apache-opennlp-1.9.4-src/opennlp-tools/src/test/java/opennlp/tools/parser/lang/en/HeadRulesTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.parser.lang.en;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.nio.charset.StandardCharsets;

import org.junit.Assert;
import org.junit.Test;

public class HeadRulesTest {

  @Test
  public void testSerialization() throws IOException {
    InputStream headRulesIn =
        HeadRulesTest.class.getResourceAsStream("/opennlp/tools/parser/en_head_rules");

    HeadRules headRulesOrginal = new HeadRules(new InputStreamReader(headRulesIn, StandardCharsets.UTF_8));

    ByteArrayOutputStream out = new ByteArrayOutputStream();
    headRulesOrginal.serialize(new OutputStreamWriter(out, StandardCharsets.UTF_8));
    out.close();

    HeadRules headRulesRecreated = new HeadRules(new InputStreamReader(
        new ByteArrayInputStream(out.toByteArray()), StandardCharsets.UTF_8));

    Assert.assertEquals(headRulesOrginal, headRulesRecreated);
  }
}
